window.Gleam.initSearch([{"doc":"themis","title":"themis","content":"# Themis\n\nPrometheus client in pure Gleam!\n\n[![Package Version](https://img.shields.io/hexpm/v/themis)](https://hex.pm/packages/themis)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/themis/)\n\n```sh\ngleam add themis\n```\n\n## Quick Start\n\n```gleam\nimport themis\nimport gleam/dict\nimport gleam/io\n\npub fn main() {\n  // Create a new themis store\n  let store = themis.new()\n\n  // Add a gauge metric\n  let assert Ok(store) = themis.add_gauge(\n    store,\n    &quot;process_memory_bytes&quot;,\n    &quot;Current memory usage in bytes&quot;,\n  )\n\n  // Record some values with labels\n  let labels = dict.from_list([\n    #(&quot;process&quot;, &quot;web_server&quot;),\n    #(&quot;instance&quot;, &quot;prod-1&quot;),\n  ])\n  \n  let assert Ok(store) = themis.insert_gauge_record(\n    store,\n    &quot;process_memory_bytes&quot;,\n    labels,\n    metrics.int(1_234_567),\n  )\n\n  // Export metrics in Prometheus format\n  io.println(metrics.print(store))\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/themis&gt;.\n\n## Usage\n\n### Working with Different Numeric Types\n\nThemis metric values are set using the dedicated `Number` type. There are 5 number types available:\n\n```gleam\nimport themis\n\n// Integer values\nlet memory = themis.int(1_234_567)\n\n// Decimal (float) values\nlet temperature = themis.dec(23.5)\n\n// Special values\nlet and_beyond = themis.pos_inf()\nlet lower_bound = themis.neg_inf()\nlet unknown = themis.nan()\n```\n\n## Output Format\n\nThe metrics are exported in the standard Prometheus text format:\n\n```\n# HELP process_memory_bytes Current memory usage in bytes\n# TYPE process_memory_bytes gauge\nprocess_memory_bytes{process=&quot;web_server&quot;,instance=&quot;prod-1&quot;} 1234567\n```\n\n## License\n\nMIT","url":"index.html"},{"doc":"themis","title":"Store","content":"pub opaque type Store\n A Store manages a collection of metrics, ensuring unique metric names.\n\nSynonyms:\nthemis.Store\nthemis Store","url":"themis.html#Store"},{"doc":"themis","title":"StoreError","content":"pub type StoreError {\n  MetricNameAlreadyInUse\n  MetricNameNotFound\n  MetricError(metric.MetricError)\n  LabelError(label.LabelError)\n}\n Represents possible errors that can occur when operating on the Store.\nMetricNameAlreadyInUse\n Returned when attempting to create a metric with a name that&#39;s already in use\n\nMetricNameNotFound\n Returned when attempting to operate on a metric that doesn&#39;t exist\n\nMetricError(metric.MetricError)\n Wraps errors related to metric name validation\n\nLabelError(label.LabelError)\n Wraps errors related to label validation\n\nSynonyms:\nthemis.StoreError\nthemis StoreError","url":"themis.html#StoreError"},{"doc":"themis","title":"add_gauge","content":"pub fn add_gauge(\n  store store: Store,\n  name name_string: String,\n  description description: String,\n) -&gt; Result(Store, StoreError)\n Adds a new gauge metric to the store.\n\n ## Arguments\n\n - `store`: The metrics store to add the gauge to\n - `name`: The name of the gauge metric (must be a valid Prometheus metric name)\n - `description`: A human-readable description of what the gauge measures\n\n ## Examples\n\n \n let assert Ok(store) = add_gauge(\n   store,\n   &quot;process_cpu_seconds_total&quot;,\n   &quot;Total user and system CPU time spent in seconds&quot;,\n )\n \nSynonyms:\nthemis.add_gauge\nthemis add_gauge","url":"themis.html#add_gauge"},{"doc":"themis","title":"dec","content":"pub fn dec(value value: Float) -&gt; Number\n Creates a Number representing a decimal value.\nSynonyms:\nthemis.dec\nthemis dec","url":"themis.html#dec"},{"doc":"themis","title":"delete_gauge","content":"pub fn delete_gauge(\n  store store: Store,\n  gauge_name name_string: String,\n) -&gt; Result(Store, StoreError)\n Removes a gauge metric and all its recorded values from the store.\n\n ## Arguments\n\n - `store`: The metrics store containing the gauge\n - `gauge_name`: The name of the gauge to delete\n\n ## Examples\n\n \n let assert Ok(store) = delete_gauge(store, &quot;process_cpu_seconds_total&quot;)\n \nSynonyms:\nthemis.delete_gauge\nthemis delete_gauge","url":"themis.html#delete_gauge"},{"doc":"themis","title":"insert_gauge_record","content":"pub fn insert_gauge_record(\n  store store: Store,\n  gauge_name name_string: String,\n  labels labels_dict: Dict(String, String),\n  value value: Number,\n) -&gt; Result(Store, StoreError)\n Records a value for a gauge metric with the given labels.\n\n ## Arguments\n\n - `store`: The metrics store containing the gauge\n - `gauge_name`: The name of the gauge to record a value for\n - `labels`: A dictionary of labels\n - `value`: The numeric value to record\n\n ## Examples\n\n \n let labels = dict.from_list([#(&quot;instance&quot;, &quot;localhost:9090&quot;)])\n let assert Ok(store) = insert_gauge_record(\n   store,\n   &quot;process_cpu_seconds_total&quot;,\n   labels,\n   int(42),\n )\n \nSynonyms:\nthemis.insert_gauge_record\nthemis insert_gauge_record","url":"themis.html#insert_gauge_record"},{"doc":"themis","title":"int","content":"pub fn int(value value: Int) -&gt; Number\n Creates a Number representing an integer value.\nSynonyms:\nthemis.int\nthemis int","url":"themis.html#int"},{"doc":"themis","title":"nan","content":"pub fn nan() -&gt; Number\n Creates a Number representing NaN (Not a Number).\nSynonyms:\nthemis.nan\nthemis nan","url":"themis.html#nan"},{"doc":"themis","title":"neg_inf","content":"pub fn neg_inf() -&gt; Number\n Creates a Number representing negative infinity.\nSynonyms:\nthemis.neg_inf\nthemis neg_inf","url":"themis.html#neg_inf"},{"doc":"themis","title":"new","content":"pub fn new() -&gt; Store\n Creates a new empty metrics store.\nSynonyms:\nthemis.new\nthemis new","url":"themis.html#new"},{"doc":"themis","title":"pos_inf","content":"pub fn pos_inf() -&gt; Number\n Creates a Number representing positive infinity.\nSynonyms:\nthemis.pos_inf\nthemis pos_inf","url":"themis.html#pos_inf"},{"doc":"themis","title":"print","content":"pub fn print(metrics_store store: Store) -&gt; String\n Formats all metrics in the store as a Prometheus-compatible text string.\n\n ## Examples\n\n \n let metrics_text = print(store)\n // HELP my_gauge My first gauge\n // TYPE my_gauge gauge\n // my_gauge{foo=&quot;bar&quot;} 10\n // my_gauge{toto=&quot;tata&quot;,wibble=&quot;wobble&quot;} +Inf\n \nSynonyms:\nthemis.print\nthemis print","url":"themis.html#print"},{"doc":"themis","title":"themis","content":"","url":"themis.html"}]);